@@ -1,3 +1,4 @@
+import django
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ValidationError
 from django.test import TestCase, override_settings
@@ -39,7 +40,7 @@ class ValidatePathTestCase(TestCase):
 
 class ValidateBooleanTestCase(TestCase):
     def test_invalid_boolean_strings(self):
-        """ ValidationError should be raised for invalid boolean values """
+        """ValidationError should be raised for invalid boolean values"""
         with self.assertRaises(ValidationError):
             validate_boolean("Flase")
         with self.assertRaises(ValidationError):
@@ -52,7 +53,7 @@ class ValidateBooleanTestCase(TestCase):
             validate_boolean(["foo"])
 
     def test_valid_boolean_strings(self):
-        """ Valid boolean values should not raise ValidationError """
+        """Valid boolean values should not raise ValidationError"""
         validate_boolean(True)
         validate_boolean(False)
         validate_boolean(1)
@@ -87,8 +88,13 @@ class ValidateDateTestCase(TestCase):
     def test_invalid_date_strings(self):
         with self.assertRaises(ValidationError):
             validate_date("tomorrowish")
-        with self.assertRaises(ValidationError):
-            validate_date("2020-04-01")
+
+        # Django 4.0 relies on Python 3.7+'s `datetime.fromisoformat()`, which
+        # handles this where the old regex did not. This is now valid when on
+        # Django 4.0+. See https://github.com/django/django/pull/14582
+        if django.VERSION < (4, 0):
+            with self.assertRaises(ValidationError):
+                validate_date("2020-04-01")
 
     def test_valid_date_strings(self):
         validate_date("2020-04-01T12:00")
